import React from 'react';
import { ComponentsType, DataType, iProperty, TagType } from '../../base/type';
import IOTIcon from './IOTIcon';
import { iIOTElementIconProps } from './interface';
import iGrapesJSConfig from '../../type';
import { iIOTElementIconJSON } from '.';
import { mergeParameters } from '../../base/utils';

const grapesJSConfig: iGrapesJSConfig<iIOTElementIconJSON, iIOTElementIconProps> = {
  type: [ComponentsType.Element],
  id: 'IOTIcon',
  tag: TagType.IOTIcon,
  access: 'r',
  render: (jsonData, ...args) => {
    const props = mergeParameters(jsonData, ...args);
    return <IOTIcon {...props}></IOTIcon>;
  },
  buildData: (mock: boolean = false, property?: iProperty) => {
    if (property === undefined) return;
    const props: iIOTElementIconJSON = {
      title: property['display-name'],
      icon: { value: 'insideicon-cu-1', show: true },
      streamId: property.streamName,
      type: property?.valuedef?.type,
      disabled: false,
      btnIcon:'', //按钮图标
      curValue:true
    };
    return props;
  },
  traits: () => {
    return [
      {
        type: 'upload',
        name: 'imgSrc',
        label: '图片设置'
      },
    ];
  },
};
export default grapesJSConfig;
