import React from 'react';
import { ComponentsType, DataType, iProperty, TagType } from '../../base/type';
import IOTGrid from './IOTGrid';
import { IOTGridProps } from './interface';
import iGrapesJSConfig from '../../type';
import { iIOTGridJSON } from '.';
import { mergeParameters } from '../../base/utils';
import { getEnumItems } from '../IOTCordEntryEnum/grapesjsConfig';

 const grapesJSConfig: iGrapesJSConfig<iIOTGridJSON, IOTGridProps> = {
   type: [ComponentsType.EnumType],
   id: 'IOTGrid',
   tag: TagType.IOTGrid,
   access: 'rw',
   render: (jsonData, ...args) => {
     const props = mergeParameters(jsonData, ...args);
     return <IOTGrid {...props}></IOTGrid>;
   },
   buildData: (mock: boolean = false, property?: iProperty) => {
     if (property === undefined) return;
     //区分类
     const props: iIOTGridJSON = {
       title: property['display-name'],
       icon: { value: 'insideicon-cu-1', show: true },
       streamId: property.streamName,
       type: property?.valuedef?.type,
       disabled: false,
      //  handler: function (val: any): void {
      //    throw new Error('Function not implemented.');
      //  },
       items: getEnumItems(property),
       styleType: '1',
     };
     return props;
   },
   traits: () => {
     return [
       {
         type: 'option-icon',
         name: 'icon',
         label: '显示图标',
       },
       {
         type: 'text',
         name: 'title',
         label: '',
       },
       {
         type: 'select',
         name: 'styleType',
         label: '选择样式',
         options: [
           { value: '1', text: '矩形文本样式' },
           { value: '2', text: '椭圆文本样式' },
         ],
       },
       {
         type: 'solt-text',
         name: 'items',
         label: '枚举列表',
       },
     ];
   },
 };
export default grapesJSConfig;
