import React, { useCallback, useEffect, useRef, useState } from 'react';
import { dotInfoList } from "../../sliderConfig";
import SliderControl from "../../SliderControl";
import './index.less';


interface SliderProps {
  leftIcon?: string;
  rightIcon?: string;
  curValue: string | number | object;
  onchange: (val: any) => void;
  start: () => void;
  min: number;
  max: number;
  step: number;
  disabled: boolean;
  unit: string;
  barStyle?: 'line';
  intType?:string;
  showHandleBtn: boolean;
  move: (val: any) => void;
  isStep?: boolean;
  dotsData?: any;  /**
                       * 滑杆下面的文字信息列表,有级时 以此来判断份几级
                       * dots是一组json对象组成的数组;
                       * 包含的字段: value、text、icon;
                       * 例: [{value: 10, text: '低档', icon: model-cool},{value: 20, text: '中档',                    icon: model-cool}];
                       **/
}
//  布局组件
const IOTNumberSlider = ({
  leftIcon = "insideicon-reduce",
  rightIcon = "insideicon-plus",
  barStyle = 'line',
  curValue,
  min,
  max,
  unit,
  intType,
  disabled,
  onchange,
  dotsData,
  step,
  start,
  move,
  isStep = true,
  showHandleBtn = true,
}: SliderProps) => {
  const [progress, setProgress] = useState<string>('');

  const [currentVal, setCurrentVal] = useState(0);
  // const [domParent,setDomParent] = useState();
  const refProgess = useRef(null);

  useEffect(() => {
    // console.log('Slider, useEffect, curValue', curValue);
    if (curValue !== void 0) {
      if (typeof curValue === 'string') {
        if (Number.parseFloat(curValue) < min) {
          setCurrentVal(min);
          setProgress(min + '%');
          return;
        } else if (Number.parseFloat(curValue) > max) {
          setCurrentVal(max);
          setProgress(max + '%');
          return;
        }
        setCurrentVal(Number.parseFloat(curValue));
        let processPercent = (Number.parseFloat(curValue) - min) * (100 / (max - min));
        setProgress(processPercent + '%');
      }
    }
  }, [curValue, min, max, barStyle]);

  useEffect(() => {
    if (currentVal !== void 0) {
      if (currentVal < min) {
        setProgress(min + '%');
        return;
      } else if (currentVal > max) {
        setProgress(max + '%');
        return;
      }
      let processPercent = (currentVal - min) * (100 / (max - min));
      setProgress(processPercent + '%');
    }
  }, [currentVal]);

  useEffect(() => {
    if (isStep) return;
    // 判断传入的value类型是否是json object;
    // value 与 this.currentValue 是否一致;
    let isSame = true;
    // 判断val是否是json对象
    if (typeof curValue === 'object') {
      // 判断this.currentValue是否是json对象
      if (Object.prototype.toString.call(currentVal).toLowerCase() !== '[object object]') {
        isSame = false;
      } else {
        // 通过对比value 与 this.currentValue 是否一致;
        isSame = ((curValue as any).text === (currentVal as any).text) || ((curValue as any).value === (currentVal as any).value);
      }
    } else {
      // 通过对比value 与 this.currentValue 是否一致;
      isSame = curValue === currentVal;
    }
    // 如果不一致 或者dots产生了变化 执行更新方法;
    if (!isSame) {
      // 无级
      if (isStep) {
        if (curValue < min) {
          setCurrentVal(min);
          return;
        } else if (curValue > max) {
          setCurrentVal(max);
          return;
        }
        setProgress(JSON.stringify(((curValue as any) - min) * (100 / (max - min))));
      } else {
        let currentStepInd = 0;
          for (const [index, elem] of (dotsData).entries()) {
            if ((curValue as any) === JSON.stringify(elem.text)) {
              currentStepInd = index;
            }
          }
        setProgress(dotInfoList(dotsData)[currentStepInd]?.left + '%');
      }
    }
  }, [curValue, min, max, barStyle, isStep])

  const setProcessPercent = useCallback(
    (processPercent: number) => {
      let currentValue: number = 0;
      if (isStep) {
        const valueDiff: number = max - min;
        if (processPercent <= 0) {
          processPercent = 0;
          currentValue = min;
        } else if (processPercent >= 100) {
          processPercent = 100;
          currentValue = max;
        } else {
          const s: number = (valueDiff * processPercent) / 100 + min;
          currentValue = parseInt(s.toString());
        }
      }  //有极
      else {
        // 步长百分比值(每级所占整个slide长度的百分比值);
        const oneStepPercent = 100 / (dotsData.length - 1);
        // 1是最小值
        let currentStep = Math.round(processPercent / oneStepPercent) + 1;
        if (currentStep < 1) {
          currentStep = 1
        }
        if (currentStep > dotsData.length) {
          currentStep = dotsData.length
        }
        processPercent = dotInfoList(dotsData)[currentStep - 1]?.left;
          currentValue = dotsData[currentStep - 1].text;
      }
      move(currentValue);
      setCurrentVal(currentValue);
      setProgress(processPercent + '%');
    },
    [max, min]
  );

  const SliderChildern = SliderControl({
    start: () => { start() },
    processHanlder: (processVal: any) => { setProcessPercent(processVal) },
    onchange: (changVal: any) => { onchange(changVal) },
    currentVal,
    refProgess
  });

  return (
    <div className="iot-number-slider">
      <div className="number-change">
        <span className="number-value">{intType !== 'float' ?currentVal :currentVal.toFixed(1)}</span>  <span className="number-unit">{unit}</span>
      </div>
      <div className="number-slider">
        <div
          className={`icon icon-left ${leftIcon}`}
          onClick={() => {
            if (disabled) return;
            const addValue = currentVal * 10 - step * 10;
            const value = addValue / 10 < min ? min : addValue / 10;
            setCurrentVal(value);
            onchange(value);
          }}
        ></div>
        <div className={`slider-bar slider-bar-${barStyle}`}>
          <div className="slider-bar-inner" ref={refProgess}>
            <div className="progress" style={{ width: progress }}>
              <div
                className="ball"
                {...SliderChildern}
              ></div>
            </div>
            {/* <div className="min-max">
                            <div className="min">{min}</div>
                            <div className="max">{max}</div>
                        </div> */}
          </div>
        </div>

        <div
          className={`icon icon-right ${rightIcon}`}
          onClick={() => {
            if (disabled) return;
            const addValue = currentVal * 10 + step * 10;
            const value =
              addValue / 10 > max ? max : addValue / 10;
            setCurrentVal(value);
            onchange(value);

          }}
        ></div>

      </div>

    </div>
  );
};

export default IOTNumberSlider;
