
import React from 'react';
import { ComponentsType, DataType, iProperty, TagType } from '../../base/type';
import IOTCordEntryNumber from './IOTCordEntryNumber';
import { IOTCordEntryNumberProps } from './interface';
import iGrapesJSConfig from '../../type';
import { iIOTCordEntryNumberJSON } from '.';
import { mergeParameters } from '../../base/utils';

const grapesJSConfig: iGrapesJSConfig<iIOTCordEntryNumberJSON, IOTCordEntryNumberProps> = {
  type: [ComponentsType.NumberType],
  id: 'IOTCordEntryNumber',
  tag: TagType.IOTCordEntryNumber,
  access: 'rw',
  render: (jsonData, ...args) => {
    const props = mergeParameters(jsonData, ...args);
    return <IOTCordEntryNumber {...props}></IOTCordEntryNumber>;
  },
  buildData: (mock: boolean = false, property?: iProperty) => {
    if (property === undefined) return;
    //区分类
    const props: IOTCordEntryNumberProps = {
      type: property.valuedef.type,
      streamId: property.streamName,
      title: property['display-name'],
      subTitle: {
        show: true,
        value: '副标题',
      },
      icon: {
        value: 'insideicon-cu-1',
        show: true,
      },
      curValue: property?.valuedef?.specs?.min,
      unit: property?.valuedef?.specs?.unit,
      min: property['valuedef']['specs']['min'],
      max: property['valuedef']['specs']['max'],
      unitdesc: property?.valuedef?.specs?.unitdesc,
      step: property['valuedef']['specs']['step'],
      intType:property['valuedef']['type'],
      disabled: false,
      streamName: '',
    };
    return props;
  },
  traits: () => {
    return [
      {
        type: 'option-icon',
        name: 'icon',
        label: '显示图标',
      },
      {
        type: 'text',
        name: 'title',
        label: '',
      },
      {
        type: 'option-text',
        name: 'subTitle',
        label: '副标题',
      },
    ];
  },
};
export default grapesJSConfig;