import React from 'react';
import { ComponentsType, DataType, iBoolProps, iProperty, TagType } from '../../base/type';
import IOTTimeSlider from './IOTTimeSlider';
import { IOTTimeSliderProps } from './interface';
import iGrapesJSConfig from '../../type';
import { iIOTTimeSliderJSON, UnitType } from '.';
import { mergeParameters } from '../../base/utils';

const grapesJSConfig: iGrapesJSConfig<iIOTTimeSliderJSON, IOTTimeSliderProps> = {
  type: [ComponentsType.NumberType],
  id: 'IOTTimeSlider',
  tag: TagType.IOTTimeSlider,
  access: 'rw',
  render: (jsonData, ...args) => {
    const props = mergeParameters(jsonData, ...args);
    return <IOTTimeSlider {...jsonData}></IOTTimeSlider>;
  },
  buildData: (mock: boolean = false, property?: iProperty) => {
    if (property === undefined) return;
    const getConver = (unit: string) => {
      var timeConver = {
        hoursFlag: false,
        minutesFlag: false,
        secondsFlag: false,
        descText: '',
      };
      if (unit === 'h') {
        timeConver.hoursFlag = true;
      } else if (unit === 'min') {
        timeConver.minutesFlag = true;
      } else if (unit === 's') {
        timeConver.secondsFlag = true;
      }
      return timeConver;
    };
    //区分类
    const props: IOTTimeSliderProps = {
      type: property.valuedef.type,
      streamId: property.streamName,
      title: property['display-name'],
      subTitle: {
        show: true,
        value: '副标题',
      },
      icon: {
        value: 'insideicon-cu-1',
        show: true,
      },
      disabled: false,
      streamName: '',
      curValue: property?.valuedef?.specs?.min,
      timeConver: getConver(property?.valuedef?.specs?.unit),
      unit: property?.valuedef?.specs?.unit as UnitType,
      min: property['valuedef']['specs']['min'],
      max: property['valuedef']['specs']['max'],
      unitdesc: property?.valuedef?.specs?.unitdesc,
      step: property['valuedef']['specs']['step'],
    };
    return props;
  },
  traits: () => {
    return [
      {
        type: 'option-icon',
        name: 'icon',
        label: '显示图标',
      },
      {
        type: 'text',
        name: 'title',
        label: '',
      },
      {
        type: 'time-convert',
        name: 'timeConver',
        label: '时间格式',
      },
    ];
  },
};
export default grapesJSConfig;