/// <reference types="react" />
export interface IComponent {
    children: React.ReactNode;
}
/**
 *组件样式
 *
 * @export
 * @interface ICompStyle
 */
export interface ICompStyle {
    color: string;
    fontSize: string;
    display?: string;
}
/**
 *字体图标样式
 *
 * @export
 * @interface IIconStyle
 */
export interface IIconStyle {
    color?: string;
}
/**
 *icom 图标
 *
 * @export
 * @interface IIcon
 */
export interface IIcon {
    type?: 'font' | 'url';
    icon?: any;
    style?: IIconStyle;
}
export interface iOptionString {
    value: string;
    show: boolean;
}
export interface iBaseProps {
    type: string;
    streamId: string;
    title?: string;
    icon?: iOptionString;
    subTitle?: iOptionString;
    disabled?: boolean;
    specs?: any;
    streamName?: string;
    source?: 'foot' | 'head' | undefined;
}
export interface iNumberProps extends iBaseProps {
    min: string;
    max: string;
    unit: string;
    unitdesc: string;
    step: string;
    intType?: string;
}
export interface iItem {
    text: string;
    value?: string;
    icon?: string;
    checked?: boolean;
    disabled?: boolean;
}
export interface iEnumProps extends iBaseProps {
    items: iItem[];
}
export declare const isIntType: (thingModelType: string) => boolean;
export declare const getMappingType: (thingModelType: string) => string;
export declare type iBoolProps = iBaseProps;
export declare enum DataType {
    IntType = "int",
    FloatType = "float",
    BoolType = "bool",
    EnumType = "enum"
}
export declare const getComponentsType: (type: string) => string;
export declare enum ComponentsType {
    NumberType = "number",
    BoolType = "bool",
    EnumType = "enum",
    WeatherType = "weather",
    Layout = "Layout",
    Element = "Element",
    Custom = "Custom",
    Consumables = "Consumables",
    cloudTimer = "cloudTimer",
    Navigation = "Navigation",
    IOTDataLog = "IOTDataLog",
    IOTAlert = "alert",
    IOTFaultAlarm = "IOTFaultAlarm"
}
export declare enum TagType {
    IOTWeather = "IOTWeather",
    IOTPower = "IOTPower",
    IOTSwitch = "IOTSwitch",
    IOTCardMultiText = "IOTCardMultiText",
    IOTGrid = "IOTGrid",
    IOTCordEntryEnum = "IOTCordEntryEnum",
    IOTCordEntryNumber = "IOTCordEntryNumber",
    IOTIconSlider = "IOTIconSlider",
    IOTSlider = "IOTSlider",
    IOTTimeSlider = "IOTTimeSlider",
    IOTNavBar = "IOTNavBar",
    IOTMiniCardText = "IOTMiniCardText",
    IOTImg = "IOTImg",
    IOTEntry = "IOTEntry",
    IOTIcon = "IOTIcon",
    IOTDirection = "IOTDirection",
    IOTNumberSlider = "IOTNumberSlider",
    IOTDoubleButton = "IOTDoubleButton",
    IOTPoleSlider = "IOTPoleSlider",
    IOTIconGrid = "IOTIconGrid",
    IOTExecutePower = "IOTExecutePower",
    IOTCustom = "IOTCustom",
    IOTAlert = "IOTAlert",
    IOTNoPoleSlider = "IOTNoPoleSlider",
    IOTConsumables = "IOTConsumables",
    IOTTimeTask = "IOTTimeTask",
    IOTIconNavigation = "IOTIconNavigation",
    IOTFaultAlarm = "IOTFaultAlarm",
    IOTDataLog = "IOTDataLog"
}
export interface iThingModel {
    content: iThingModelContent;
    id: string;
    updateUserId: string;
    publishedLatest: number;
    publishedUserId: string;
    isLatest: number;
    createTime: number;
    updateTime: number;
    publishedStatus: number;
    description: string;
    name: string;
    thingTypeId: string;
    thingModelVersion: string;
    class: string;
    published: boolean;
    enhanceContent: iThingModelContent;
    createUserId: string;
}
export interface iThingModelContent {
    models: iModel[];
    'display-name': string;
    description: string;
    'thing-model-version': string;
    id: string;
}
export interface iModel {
    functions: string[];
    'display-name': string;
    description: string;
    id: string;
    type: string;
    events: string[];
    key: string;
    properties: iProperty[];
}
export interface iProperty {
    description: string;
    'display-name': string;
    id: string;
    access: string;
    valuedef: iValuedef;
    key: string;
    streamName: string;
    extension?: string;
    isShowH5: number;
    label: string;
}
export interface iValuedef {
    specs: iSpecs;
    type: string;
}
export interface iSpecs {
    min: string;
    max: string;
    step: string;
    unit: string;
    unitdesc: string;
    length: string;
    size: number;
    item: {
        type: string;
        specs: any;
    };
    memberss: string;
    members: {
        type: string;
        key: string;
        specs: any;
    }[];
    values: any;
}
export interface iTrait {
    type: string;
    label: string;
    name: string;
    tips?: string;
    description?: string;
}
export interface iFunction {
    id: string;
    title: string;
    type: ComponentsType;
    displayType?: string;
    icon?: {
        value: string;
        show: boolean;
    };
    property?: iProperty;
}
