"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.condJudgmentForOne = void 0;
exports.debounce = debounce;
exports.typeConversion = exports.resolveUiStreams = exports.resolveRule = exports.mergeParameters = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _type = require("./type");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var typeConversion = function typeConversion(type, curValue) {
  return (0, _type.isIntType)(type) ? Number.parseInt(curValue + '') + '' : Number.parseFloat(curValue + '') + '';
};

exports.typeConversion = typeConversion;

var mergeParameters = function mergeParameters(jsonData) {
  var props = _objectSpread({}, jsonData);

  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  args.forEach(function (item) {
    if ((0, _typeof2.default)(item) === 'object') {
      var key = Object.keys(item)[0];
      props[key] = item[key];
    }

    if (typeof item === 'function') {
      // console.log(item.name);
      props[item.name] = item;
    }
  });
  return props;
};

exports.mergeParameters = mergeParameters;

var resolveRule = function resolveRule(attr, ruleJson, snapShot) {
  var copyData = _objectSpread({}, attr);

  var streamId = attr['streamId'];
  var rules = ruleJson[streamId];

  if (rules && rules.length > 0) {
    rules.map(function (item) {
      var ifData = item['if'];
      var thenData = item['then'];

      if (condJudgment(ifData, snapShot)) {
        copyData = _objectSpread({}, renderResolve(thenData, copyData));
      }
    });
  } // console.log(copyData, 'copyData===');


  return _objectSpread({}, copyData);
}; // 条件判断


exports.resolveRule = resolveRule;

var condJudgment = function condJudgment(ifData, snapShot) {
  var flag = false;
  var curValue = snapShot[ifData['streamId']];
  if (!curValue) return false;

  if (ifData['operator'] === '=') {
    flag = ifData['value'].toString() === curValue.toString();
  } else if (ifData['operator'] === '!=') {
    flag = ifData['value'].toString() !== curValue.toString();
  } else if (ifData['operator'] === '>') {
    flag = Number(curValue) > Number(ifData['value']);
  } else if (ifData['operator'] === '<') {
    flag = Number(curValue) < Number(ifData['value']);
  } else if (ifData['operator'] === '>=') {
    flag = Number(curValue) >= Number(ifData['value']);
  } else if (ifData['operator'] === '<=') {
    flag = Number(curValue) <= Number(ifData['value']);
  }

  return flag;
}; // 渲染数据处理判断


var renderResolve = function renderResolve(thenData, attr) {
  var obj = _objectSpread({}, attr);

  if (thenData['operator'] === 'hidden') {
    obj = {};
  } else if (thenData['operator'] === 'disabled') {
    if (JSON.stringify(obj) !== '{}') {
      obj['disabled'] = true;
    }
  } else if (thenData['operator'] === 'valueDisabled') {
    if (JSON.stringify(obj) === '{}') return;
    var types = getMappingType(thenData['type']);

    if (types === 'enum') {
      var list = obj['items'].map(function (item) {
        if (item['value'].toString() === thenData['value']) {
          item['disabled'] = item['value'].toString() === thenData['value'];
        }

        return item;
      });
      obj['items'] = (0, _toConsumableArray2.default)(list);
    } else if (types === 'bool') {
      var f = obj['curValue'].toString() === thenData['value'];
      f && (obj['curValue'] = !obj['curValue']);
    } else if (types === 'number') {// 暂不处理
    }
  } else if (thenData['operator'] === '=') {
    if (JSON.stringify(obj) === '{}') return;

    var _types = getMappingType(thenData['type']);

    if (_types === 'enum') {
      var _list = obj['items'].map(function (item) {
        item['checked'] = item['value'].toString() === thenData['value'];
        return item;
      });

      obj['items'] = (0, _toConsumableArray2.default)(_list);
    } else if (_types === 'bool') {
      obj['curValue'] = thenData['value'] === '1';
    } else if (_types === 'number') {
      obj['curValue'] = Number(thenData['value']);
    }
  } else if (thenData['operator'] === '>') {
    if (JSON.stringify(obj) === '{}') return;

    var _types2 = getMappingType(thenData['type']);

    if (_types2 === 'number') {
      obj['min'] = Number(thenData['value']) + Number(obj['step']);
    }
  } else if (thenData['operator'] === '<') {
    if (JSON.stringify(obj) === '{}') return;

    var _types3 = getMappingType(thenData['type']);

    if (_types3 === 'number') {
      obj['max'] = Number(thenData['value']) - Number(obj['step']);
    }
  } else if (thenData['operator'] === '>=') {
    if (JSON.stringify(obj) === '{}') return;

    var _types4 = getMappingType(thenData['type']);

    if (_types4 === 'number') {
      obj['min'] = Number(thenData['value']);
    }
  } else if (thenData['operator'] === '<=') {
    if (JSON.stringify(obj) === '{}') return;

    var _types5 = getMappingType(thenData['type']);

    if (_types5 === 'number') {
      obj['max'] = Number(thenData['value']);
    }
  }

  return obj;
};

var getMappingType = function getMappingType(thingModelType) {
  switch (thingModelType) {
    case 'uint8':
    case 'uint16':
    case 'uint32':
    case 'int':
    case 'int8':
    case 'int16':
    case 'int32':
    case 'int64':
      return 'number';
      break;

    case 'float':
    case 'double':
      return 'number';
      break;

    default:
      break;
  }

  return thingModelType;
}; // 控制成功后 规则联动


var resolveUiStreams = function resolveUiStreams(streamsObj, ruleJson) {
  var copyData = {};
  Object.keys(ruleJson).forEach(function (key) {
    var rules = ruleJson[key];
    Object.keys(streamsObj).forEach(function (streamId) {
      if (rules && rules.length > 0) {
        rules.map(function (item) {
          var ifData = item['if'];
          var thenData = item['then'];

          if (condJudgmentForOne(ifData, (0, _defineProperty2.default)({}, streamId, streamsObj[streamId]))) {
            copyData = _objectSpread({}, resolveThenObject(thenData, copyData));
          }
        });
      }
    });
  });
  return _objectSpread(_objectSpread({}, streamsObj), copyData);
};

exports.resolveUiStreams = resolveUiStreams;

var resolveThenObject = function resolveThenObject(thenData, attr) {
  var obj = {};

  if (thenData['operator'] === '=') {
    obj[thenData['streamId']] = thenData['value'];
  }

  return _objectSpread(_objectSpread({}, attr), obj);
};

var condJudgmentForOne = function condJudgmentForOne(ifData, streamObj) {
  var flag = false;
  var curValue = streamObj[ifData['streamId']];
  if (!curValue) return false;

  if (ifData['operator'] === '=') {
    flag = ifData['value'].toString() === curValue.toString();
  } else if (ifData['operator'] === '!=') {
    flag = ifData['value'].toString() !== curValue.toString();
  } else if (ifData['operator'] === '>') {
    flag = Number(curValue) > Number(ifData['value']);
  } else if (ifData['operator'] === '<') {
    flag = Number(curValue) < Number(ifData['value']);
  } else if (ifData['operator'] === '>=') {
    flag = Number(curValue) >= Number(ifData['value']);
  } else if (ifData['operator'] === '<=') {
    flag = Number(curValue) <= Number(ifData['value']);
  }

  return flag;
};

exports.condJudgmentForOne = condJudgmentForOne;
var timer;
/**
 * @name 防抖
 * @param fn回调
 * @param ms时间
 */

function debounce(fn, ms) {
  return function () {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    if (timer) {
      clearTimeout(timer);
      timer = null;
    } // console.log(1);


    timer = setTimeout(function () {
      // console.log(2);
      fn.apply(void 0, args);
    }, ms);
  };
}