"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isSymbolFormatTime = exports.getSymbolDisplayTime = void 0;

var _utils = require("../../number/IOTTimeSlider/utils");

var getSymbolDisplayTime = function getSymbolDisplayTime(unit, timeConver) {
  var type = '';
  if (!timeConver) return;
  var hour = timeConver.hour,
      minute = timeConver.minute,
      second = timeConver.second;

  if (hour) {
    type = 'h';
  }

  if (minute) {
    type += 'min';
  }

  if (second) {
    type += 's';
  }

  if (type === '') {
    type = unit;
  }

  return type;
};

exports.getSymbolDisplayTime = getSymbolDisplayTime;

var isSymbolFormatTime = function isSymbolFormatTime(initTime, unit, timeConver) {
  if (initTime === undefined) return '';
  var initSecond = (0, _utils.getSeconds)(initTime, unit);
  var displayTimeType = getSymbolDisplayTime(unit, timeConver);
  var res = '';
  var hour = 0;
  var mins = 0;
  var secs = 0;

  switch (displayTimeType) {
    case 'h':
      res = "".concat(Math.round(initSecond / 3600 * 100) / 100, "h");
      break;

    case 'min':
      res = "".concat(Math.round(initSecond / 60 * 100) / 100, "min");
      break;

    case 's':
      res = "".concat(initSecond, "s");
      break;

    case 'mins':
      mins = Math.floor(initSecond / 60);
      secs = initSecond % 60;
      res = "".concat(formatNumber(mins), ":").concat(formatNumber(secs));
      break;

    case 'hmins':
      hour = Math.floor(initSecond / 3600);
      mins = Math.floor(initSecond % 3600 / 60);
      secs = initSecond % 3600 % 60;
      res = "".concat(formatNumber(hour), ":").concat(formatNumber(mins), ":").concat(formatNumber(secs));
      break;

    case 'hmin':
      hour = Math.floor(initSecond / 3600);
      mins = Math.round(initSecond % 3600 / 60 * 100) / 100;
      res = "".concat(formatNumber(hour), ":").concat(formatNumber(mins));
      break;

    default:
      break;
  }

  return res;
}; //数据转化


exports.isSymbolFormatTime = isSymbolFormatTime;

function formatNumber(n) {
  n = n.toString();
  return n[1] ? n : "0" + n;
}