"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = require("react");

/**
 * 
 * @param onLongPress 长按事件
 * @param onClick 点击事件
 * @param stopLongPress 长按事件结束状态
 * @param param2 
 * @returns 
 */
var useLongPress = function useLongPress(onLongPress, onClick, stopLongPress) {
  var _ref = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {},
      _ref$shouldPreventDef = _ref.shouldPreventDefault,
      shouldPreventDefault = _ref$shouldPreventDef === void 0 ? true : _ref$shouldPreventDef,
      _ref$delay = _ref.delay,
      delay = _ref$delay === void 0 ? 300 : _ref$delay;

  var _useState = (0, _react.useState)(false),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      longPressTriggered = _useState2[0],
      setLongPressTriggered = _useState2[1];

  var timeout = (0, _react.useRef)();
  var target = (0, _react.useRef)();
  var start = (0, _react.useCallback)(function (event) {
    if (shouldPreventDefault && event.target) {
      event.target.addEventListener("touchend", preventDefault, {
        passive: false
      });
      target.current = event.target;
    }

    timeout.current = setTimeout(function () {
      onLongPress(event);
      setLongPressTriggered(true);
    }, delay);
  }, [onLongPress, delay, shouldPreventDefault]);
  var clear = (0, _react.useCallback)(function (event) {
    var shouldTriggerClick = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    timeout.current && clearTimeout(timeout.current);
    shouldTriggerClick && !longPressTriggered && onClick();

    if (longPressTriggered) {
      stopLongPress();
    }

    setLongPressTriggered(false);

    if (shouldPreventDefault && target.current) {
      target.current.removeEventListener("touchend", preventDefault);
    }
  }, [shouldPreventDefault, onClick, longPressTriggered, stopLongPress]);
  return {
    onTouchStart: function onTouchStart(e) {
      return start(e);
    },
    onTouchEnd: function onTouchEnd(e) {
      return clear(e);
    }
  };
};

var isTouchEvent = function isTouchEvent(event) {
  return "touches" in event;
};

var preventDefault = function preventDefault(event) {
  if (!isTouchEvent(event)) return;

  if (event.touches.length < 2 && event.preventDefault) {
    event.preventDefault();
  }
};

var _default = useLongPress;
exports.default = _default;