"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSeconds = exports.getDisplayTime = exports.formatTime = void 0;

/**
 * 
 * @param initTime 初始时间 默认是分钟
 * @param unit 初始单位
 * @param type 要转换的时间格式 "hh:mm:ss" | "hh:mm" | "mm:ss" | 'hh' | "mm" | "ss"
 * @returns 
 */
var getSeconds = function getSeconds(initTime, unit) {
  var ss = 0;

  switch (unit) {
    case 'h':
      ss = initTime * 60 * 60;
      break;

    case 'min':
      ss = initTime * 60;
      break;

    case 's':
      ss = initTime;
      break;

    default:
      break;
  }

  return ss;
};

exports.getSeconds = getSeconds;

var getDisplayTime = function getDisplayTime(timeConver, unit) {
  var type = '';
  var hoursFlag = timeConver.hoursFlag,
      minutesFlag = timeConver.minutesFlag,
      secondsFlag = timeConver.secondsFlag;

  if (hoursFlag) {
    type = 'h';
  }

  if (minutesFlag) {
    type += 'min';
  }

  if (secondsFlag) {
    type += 's';
  }

  if (type === '') {
    type = unit;
  }

  return type;
};

exports.getDisplayTime = getDisplayTime;

var formatTime = function formatTime(initTime, unit, timeConver) {
  if (initTime === undefined) return '';
  var initSecond = getSeconds(initTime, unit);
  var displayTimeType = getDisplayTime(timeConver, unit);
  var res = '';
  var hour = 0;
  var mins = 0;
  var secs = 0;

  switch (displayTimeType) {
    case 'h':
      res = "".concat(Math.round(initSecond / 3600 * 100) / 100, "\u5C0F\u65F6");
      break;

    case 'min':
      res = "".concat(Math.round(initSecond / 60 * 100) / 100, "\u5206\u949F");
      break;

    case 's':
      res = "".concat(initSecond, "\u79D2");
      break;

    case 'mins':
      mins = Math.floor(initSecond / 60);
      secs = initSecond % 60;
      res = mins + '分' + secs + '秒';
      break;

    case 'hmins':
      hour = Math.floor(initSecond / 3600);
      mins = Math.floor(initSecond % 3600 / 60);
      secs = initSecond % 3600 % 60;
      res = hour + "时" + mins + '分' + secs + '秒';
      break;

    case 'hmin':
      hour = Math.floor(initSecond / 3600);
      mins = Math.round(initSecond % 3600 / 60 * 100) / 100;
      res = hour + "时" + mins + '分';
      break;

    default:
      break;
  }

  return res;
};

exports.formatTime = formatTime;